"""Template Sense - AI-powered invoice template extraction library for Tako.

This package provides functionality to extract structured metadata from Excel-based
invoice templates using heuristics and AI-based classification.
"""

__version__ = "0.1.0"

# Public API will be exported here once modules are implemented
__all__ = [
    "__version__",
]
